@@ -52,9 +52,10 @@ BaremetalGroup = [
     cfg.StrOpt('catalog_type',
                default='baremetal',
                help="Catalog type of the baremetal provisioning service"),
+    # TODO(dtantsur): change to fake-hardware when Ocata is no longer supported
     cfg.StrOpt('driver',
                default='fake',
-               help="Driver name which Ironic uses"),
+               help="Driver name to use for API tests"),
     cfg.StrOpt('endpoint_type',
                default='publicURL',
                choices=['public', 'admin', 'internal',
@@ -80,6 +81,12 @@ BaremetalGroup = [
                help="Timeout for unprovisioning an Ironic node. "
                     "Takes longer since Kilo as Ironic performs an extra "
                     "step in Node cleaning."),
+    cfg.IntOpt('rescue_timeout',
+               default=300,
+               help="Timeout for rescuing an Ironic node."),
+    cfg.IntOpt('unrescue_timeout',
+               default=300,
+               help="Timeout for unrescuing an Ironic node."),
     cfg.StrOpt('min_microversion',
                help="Lower version of the test target microversion range. "
                     "The format is 'X.Y', where 'X' and 'Y' are int values. "
@@ -113,13 +120,24 @@ BaremetalGroup = [
     cfg.ListOpt('enabled_hardware_types',
                 default=['ipmi'],
                 help="List of Ironic enabled hardware types."),
+    cfg.ListOpt('enabled_bios_interfaces',
+                default=['fake'],
+                help="List of Ironic enabled bios interfaces."),
     cfg.ListOpt('enabled_deploy_interfaces',
                 default=['iscsi', 'direct'],
                 help="List of Ironic enabled deploy interfaces."),
+    cfg.ListOpt('enabled_rescue_interfaces',
+                default=['no-rescue'],
+                help="List of Ironic enabled rescue interfaces."),
+    cfg.StrOpt('default_rescue_interface',
+               help="Ironic default rescue interface."),
     cfg.IntOpt('adjusted_root_disk_size_gb',
                min=0,
                help="Ironic adjusted disk size to use in the standalone tests "
                     "as instance_info/root_gb value."),
+    cfg.IntOpt('available_nodes', min=0, default=None,
+               help="The number of baremetal hosts available to use for "
+                    "the tests.")
 ]
 
 BaremetalFeaturesGroup = [
@@ -168,4 +186,10 @@ BaremetalIntrospectionGroup = [
                 help="Is the auto-discovery feature enabled. Enroll hook "
                      "should be specified in node_not_found_hook - processing "
                      "section of inspector.conf"),
+    cfg.StrOpt('auto_discovery_default_driver',
+               # TODO(dtantsur): change to fake-hardware when Queens is no
+               # longer supported.
+               default='fake',
+               help="The driver expected to be set on newly discovered nodes. "
+                    "Only has effect with auto_discovery_feature is True."),
 ]
